simsopt package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   _core <simsopt_user._core>
   configs <simsopt_user.configs>
   field <simsopt_user.field>
   geo <simsopt_user.geo>
   mhd <simsopt_user.mhd>
   objectives <simsopt_user.objectives>
   solve <simsopt_user.solve>
   util <simsopt_user.util>
